@@ -7,7 +7,9 @@ that result in runtime exceptions. It's Bad.
 
 This file aims to manually do some pre-parsing on the Yaml strings before
 decoding to ensure that whichever version of Python is doing the decoding
-can successfully parse the string.
+can successfully parse the string. Since this library now only supports
+Python 3, we only need to support reading Python 2-written strings in
+Python 3, not vice versa.
 
 Russell Cottrell's wonderful Surrogate Pair Calculator
 (http://www.russellcottrell.com/greek/utilities/SurrogatePairCalculator.htm)
@@ -18,12 +20,10 @@ element is between 0xD800 and 0xDBFF, and the second element is between
 """
 
 import re
-import sys
 
 PY2_SURROGATE_PAIR_RE = re.compile(
     r'\\u([Dd][89a-bA-B][0-9a-fA-F]{2})\\u([Dd][c-fC-F][0-9a-fA-F]{2})'
 )
-PY3_MULTIBYTE_RE = re.compile(r'\\U([A-Fa-f0-9]{8})')
 
 
 def from_surrogate_pair(high, low):
@@ -51,17 +51,5 @@ def to_py3_compatible(input):
     return input
 
 
-def to_py2_compatible(input):
-    """Convert an input string containing UTF-16 to Unicode surrogate pairs"""
-    for multibyte_char in PY3_MULTIBYTE_RE.findall(input):
-        high, low = to_surrogate_pair(multibyte_char)
-        input = input.replace("\\u%s" % multibyte_char, "\\u%04x\\u%04x" % (high, low))
-        input = input.replace("\\U%s" % multibyte_char, "\\u%04x\\u%04x" % (high, low))
-    return input
-
-
 def fix_unicode(input):
-    if sys.version_info[0] >= 3:
-        return to_py3_compatible(input)
-    else:
-        return to_py2_compatible(input)
+    return to_py3_compatible(input)
